# -*- coding: utf-8 -*-
# @Time    : 2021/01/05 22:53:23 
# @Author  : ddvv
# @Site    : https://ddvvmmzz.github.io
# @File    : about.py 
# @Software: Visual Studio Code

__all__ = [
    "__author__",
    "__copyright__",
    "__email__",
    "__license__",
    "__summary__",
    "__title__",
    "__uri__",
    "__version__",
]

__title__ = "mmts"
__summary__ = "MM tools script"
__uri__ = "https://github.com/a232319779/mmts"
__version__ = "0.0.2"
__author__ = "ddvv"
__email__ = "dadavivi512@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2019-2022 %s" % __author__